pub struct BaseValuePrinter<'a> {
pub base: &'a BaseValues,
pub ty: BaseValueId,
pub val: Value,
}Expand description
A wrapper used to print a base value.
The given base value type must be registered with the BaseValues instance,
otherwise attempting to call the Debug implementation will panic.
Fields
base: &'a BaseValuesty: BaseValueIdval: ValueTrait Implementations