pub struct TableSpec {
pub n_keys: usize,
pub n_vals: usize,
pub uncacheable_columns: DenseIdMap<ColumnId, bool>,
pub allows_delete: bool,
}Fields
n_keys: usizeThe number of key columns for the table.
n_vals: usizeThe number of non-key (i.e. value) columns in the table.
The total “arity” of the table is n_keys + n_vals.
uncacheable_columns: DenseIdMap<ColumnId, bool>Columns that cannot be cached across generations.
These columns should (e.g.) never have indexes built for them, as they will go out of date too quickly.
allows_delete: boolWhether or not deletions are supported for this table.
Tables where this value is false are allowed to panic on calls to
stage_remove.
Implementations