Structs
- AtomId
- A component of a query consisting of a function and a list of variables or constants
- Base
Value Id - an identifier for base value types
- Base
Value Printer - A wrapper used to print a base value.
- Base
Values - A registry for base value types and functions on them.
- Boxed
- A newtype wrapper used to implement the
BaseValuetrait on types not defined in this crate. - Cached
Plan - A cached plan for a given rule.
- Column
Id - a particular column in a table
- Container
Rebuild Summary - Summary returned by container rebuild.
- Container
Value Id - an identifier for containers
- Container
Values - Counter
Id - A counter accessible to actions, useful for generating unique Ids.
- Database
- A collection of tables and indexes over them.
- Displaced
Table - A special table backed by a union-find used to efficiently implement egglog-style canonicaliztion.
- Execution
State - A handle on a database that may be in the process of running a rule.
- External
Function Id - A user-defined operation that can be invoked from a query
- Offset
- an opaque offset token – used to encode iterations over a table (within a generation). These always start at 0.
- Offset
Range - Pool
- A shared pool of objects.
- PoolSet
- Pooled
- An owned value of type
Tthat can be returned to a memory pool when it is no longer used. - Query
Builder - Builder for the “query” portion of the rule.
- Row
- A row in a table.
- RowId
- a numeric offset into a table
- Rule
Builder - Builder for the “action” portion of the rule.
- RuleId
- An identifier for a rule in a rule set
- RuleSet
- A set of rules to run against a
Database. - Rule
SetBuilder - Builder for a
RuleSet. - Sorted
Writes Table - Table
Change - A summary of the kinds of changes that a table underwent after a merge operation.
- TableId
- a table in the database
- Table
Spec - Table
Version - The version of a table.
- Tagged
RowBuffer - A
TaggedRowBufferwraps aRowBufferbut also keeps track of a sourceRowIdfor the row it contains. This makes it useful for materializing the contents of aSubsetof a table. - Tuple
Index - A mapping from keys to subsets of rows.
- Value
- A generic identifier representing an egglog value
- Variable
- a variable in a query
- Wrapped
Table - A WrappedTable takes a Table and extends it with a number of helpful, object-safe methods for accessing a table.
Enums
- Constraint
- A constraint on the values within a row.
- Merge
Val - A value that can be written to the database during a merge action.
- Plan
Strategy - The algorithm used to produce a join plan.
- Query
Entry - A representation of a value within a query or rule.
- Query
Error - Subset
- Either or an offset range or a sorted offset vector.
- Subset
Ref - Write
Val - A value that can be written to a table in an action.
Traits
- Base
Value - A simple data type that can be interned in a database.
- Container
Value - A trait implemented by container types.
- External
Function - External functions allow external callers to manipulate database state in near-arbitrary ways.
- Mutation
Buffer - A trait specifying a buffer of pending mutations for a
Table. - Rebuilder
- Custom functions used for tables that encode a bulk value-level rebuild of other tables.
- Table
- An interface for a table.
- Value
Rebuilder - Remap individual values (e.g. to their union-find leaders) — the value-level
half of rebuilding, enough to rebuild a single container’s contents (see
crate::ContainerValue::rebuild_contents).
Functions
- make_
external_ func - Automatically generate an
ExternalFunctionimplementation from a function.
Type Aliases
- External
Context - A borrowed value an embedder can make visible to every
ExecutionStatecreated for one operation, for itsExternalFunctions to read back withExecutionState::external_context. - MergeFn
- The type of closures that are used to merge values in a
SortedWritesTable.